@@ -59,7 +59,7 @@ Readonly::Scalar our $STRINGIFY              => 'Dumper';
 use Amazon::API::Constants qw( :all );
 use Amazon::API::Botocore::Pod qw( pod );
 
-our $VERSION = '2.1.0';  ## no critic (RequireInterpolationOfMetachars)
+our $VERSION = '2.1.1';  ## no critic (RequireInterpolationOfMetachars)
 
 our %BOTO_SERVICES;
 
@@ -718,7 +718,7 @@ sub get_service_descriptions {
     my $service_file    = "$service_path/service-2.json";
     my $paginators_file = "$service_path/paginators-1.json";
 
-    my $paginators = fetch_paginators($paginators_file);
+    my $paginators = eval { return fetch_paginators($paginators_file); };
 
     my $service_description = fetch_service_description($service_file);
 
@@ -1196,7 +1196,7 @@ our @API_METHODS = qw(
 @actions@
 );
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.1.1';
 
 sub new {
   my ( $class, @options ) = @_;
